django-superform: nest all the forms!
=====================================

A ``SuperForm`` lets you nest other forms and formsets inside a form. That way
handling multiple forms on one page gets *super* easy.

**Contents:**

.. toctree::
    :maxdepth: 2

    quickstart
    forms
    fields
    changelog

:ref:`genindex` | :ref:`modindex` | :ref:`search`
